as-character-eseq: String representation of an event sequence object

as.character.eseqR Documentation

String representation of an event sequence object

Description

Generic as.character methods to get a string representation of an event sequence seqelist object and of an element eseq of an event sequence object.

Usage

## S3 method for class 'seqelist'
as.character(x, ...)
## S3 method for class 'eseq'
as.character(x, ...)

Arguments

x

Event sequence seqelist or esqe object to be coerced

...

Further arguments passed to other methods

Details

String representations have the following form: time-(e1,e2,...)-elapsedtime-(e3,...)... where time is the time elapsed from start to the first set of simultaneous events (e1,e2,...) and elapsedtime the time between two consecutive sets of simultaneous events. Time is only displayed when events are time stamped.

Author(s)

Matthias Studer (with Gilbert Ritschard for the help page)

See Also

seqecreate and print.seqelist for other methods applying to event sequence objects.

Examples

data(actcal.tse)
actcal.eseq <- seqecreate(actcal.tse)
head(as.character(actcal.eseq))

TraMineR documentation built on Sept. 16, 2026, 1:06 a.m.