Learn R Programming

TraMineR (version 1.0)

seqdplot: Graphic presenting the states frequencies

Description

Graphic presenting the states frequencies for each time unit, as computed by the seqstatd function.

Usage

seqdplot(seqdata, cpal=NULL, title=NULL, 
         withlegend=TRUE, withborder=TRUE, ltext=NULL, xtlab=NULL, bmar=1)

Arguments

seqdata
a sequence object created with the seqdef function.
cpal
alternative color palette to use for the states. If user specified, a vector of colors with number of elements equal to the number of distinct states. By default, the 'cpal' attribute of the 'seqdata' sequence object is used (see
title
a character string giving the title for the graphic. Default to no title
withlegend
logical variable indicating wether a legend for the states colors is plotted. Default to TRUE
withborder
if TRUE, plots the borders of the bars. Default to TRUE.
ltext
optional description of the states to appear in the legend. Must be a vector of character strings with number of elements equal to the number of distinct states. If unspecified, the 'label' attributes of the 'seqdata' sequence object is used (see
xtlab
optional labels for the x axis ticks labels. If unspecified, the column names of the 'seqdata' sequence object are used (see seqdef).
bmar
base margin for the top and bottom of the graphic, that is, the amount of white space surrouding it.

See Also

seqstatd

Examples

Run this code
## Loading the 'biofam' example data set
data(biofam)

## Defining a sequence object with the data in columns 10 to 25
## (family status from age 15 to 30)
biofam.seq <- seqdef(biofam,10:25,informat='STS')

## Plotting the states distribution (family status from age 15 to 30)
seqdplot(biofam.seq)

Run the code above in your browser using DataLab