seqe: Event sequence object

is.seqelistR Documentation

Event sequence object

Description

TraMineR uses an internal event sequence object for all its operations with event sequences such as mining frequent subsequences.

Function is.seqelist checks wether the argument is an event sequence object while is.eseq checks wether the argument is a single element of an event sequence object.

is.seqe() has been removed in TraMineR 2.0-4, use is.eseq() instead.

There are subsetting, print, plot, levels, and str methods that apply to event sequence objects and their elements. The summary method applies to seqelist objects and returns number of sequences, size of the alphabet, and summary values of number of transitions per sequence and sequence durations.

Usage

is.eseq(eseq, s)
is.seqelist(eseq, s)
## S3 method for class 'eseq'
print(x, quote=FALSE, ...)
## S3 method for class 'seqelist'
print(x, quote=FALSE, ...)
## S3 method for class 'eseq'
plot(x, type="pc", ...)
## S3 method for class 'seqelist'
plot(x, type="pc", ...)
## S3 method for class 'eseq'
levels(x, ...)
## S3 method for class 'seqelist'
levels(x, ...)
## S3 method for class 'eseq'
str(object, ...)
## S3 method for class 'seqelist'
str(object, ...)
## S3 method for class 'eseq'
summary(object, ...)
## S3 method for class 'seqelist'
summary(object, ...)

Arguments

eseq

Sequence object

x, object

eseq or seqelist object

quote

logical, should strings be printed with surrounding quotes?

type

string, currently only "pc" (parallel coordinate plot) is supported

...

further arguments to other functions or methods.

s

Deprecated. Use eseq instead.

Value

The summary method applies to seqelist objects and returns number of sequences, size of the alphabet, and summary values of sequence durations (dur) and number of transitions (ntrans) per sequence. It also returns transparently the vectors $dur of sequence durations and $ntrans of number of transitions. When applied to an element of a seqelist, it returns the values of ntrans and dur of the selected element and nalph, the size of the alphabet.

Author(s)

Matthias Studer and Gilbert Ritschard

See Also

seqpcplot, as.character.seqelist, and as.character.eseq, the latter two for character string representations of event sequence objects

Examples

data(ex1)
sqex1 <- seqdef(ex1[,1:13])
esqex1 <- seqecreate(sqex1)
## esqex1 is a list of event sequences
is.seqelist(esqex1)
## alphabet of the event sequence object
levels(esqex1)
## can also be extracted with
alphabet(esqex1)

is.eseq(esqex1[[1]])

(res <- summary(esqex1))
res$ntrans
res$dur

summary(esqex1[[3]])

TraMineR documentation built on Sept. 16, 2026, 1:06 a.m.