Learn R Programming

TraMineR (version 1.0)

seqefplot: Plot frequencies of subsequences

Description

Plot frequencies of subsequences. If a group is specified, plot de difference of subsequence frequencies by the factor.

Usage

seqefplot(subseq, seqe, group = NULL, mfrow=c(2,3),...)

Arguments

subseq
The subsequences to plot
seqe
The list of individual sequences
group
A factor or a vector describing a group
mfrow
When a group is used, a 2-length vector specifying the number of column and row (by default, only one row)
...
arguments passed to par and boxplot commands

Examples

Run this code
## loading data
data(actcal.tse)

## creating sequences
actcal.seqe <- seqecreate(actcal.tse$id,
	actcal.tse$time,
	actcal.tse$event)

## Looking for frequent subsequences
fsubseq <- seqefsub(actcal.seqe,pMinSupport=0.01)

## Frequence of first ten subsequences
seqefplot(fsubseq$subseq[1:10],actcal.seqe)

## Retrieve sex information

data(actcal)
## Plotting on 2 line 3 column
seqefplot(fsubseq$subseq[1:6],actcal.seqe, 
	group=actcal$sex, mfrow=c(2,3))

Run the code above in your browser using DataLab