| as.character.eseq | R Documentation |
Generic as.character methods to get a string representation of an event sequence seqelist object and of an element eseq of an event sequence object.
## S3 method for class 'seqelist'
as.character(x, ...)
## S3 method for class 'eseq'
as.character(x, ...)
x |
Event sequence |
... |
Further arguments passed to other methods |
String representations have the following form:
time-(e1,e2,...)-elapsedtime-(e3,...)...
where time is the time elapsed from start to the first set of simultaneous events (e1,e2,...) and elapsedtime the time between two consecutive sets of simultaneous events. Time is only displayed when events are time stamped.
Matthias Studer (with Gilbert Ritschard for the help page)
seqecreate and print.seqelist for other methods applying to event sequence objects.
data(actcal.tse)
actcal.eseq <- seqecreate(actcal.tse)
head(as.character(actcal.eseq))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.